@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021 -- leonerd@leonerd.org.uk
 
-package XS::Parse::Keyword 0.13;
+package XS::Parse::Keyword 0.14;
 
 use v5.14;
 use warnings;
@@ -42,7 +42,7 @@ and parsing hooks.
 I<ver> should either be 0 or a decimal number for the module version
 requirement; e.g.
 
-   boot_xs_parse_keyword(0.01);
+   boot_xs_parse_keyword(0.14);
 
 =head2 register_xs_parse_keyword
 
@@ -176,6 +176,7 @@ function, using a C<struct> type consisting of the following fields:
             SV *value;
          } attr;
          PADOFFSET padix;
+         struct XSParseInfixInfo *infix;
       };
       int line;
    } XSParseKeywordPiece;
@@ -364,6 +365,22 @@ I<atomic, can probe, emits nothing.>
 
 A literal character (C<,>, C<:> or C<=>) is expected. No argument value is passed.
 
+=head2 XPK_INFIX_*
+
+I<atomic, can probe, emits infix.>
+
+An infix operator as recognised by L<XS::Parse::Infix>. The returned pointer
+points to a structure allocated by C<XS::Parse::Infix> describing the
+operator.
+
+Various versions of the macro are provided, each using a different selection
+filter to choose certain available infix operators:
+
+   XPK_INFIX_RELATION         # any relational operator
+   XPK_INFIX_EQUALITY         # an equality operator like `==` or `eq`
+   XPK_INFIX_MATCH_NOSMART    # any sort of "match"-like operator, except smartmatch
+   XPK_INFIX_MATCH_SMART      # XPK_INFIX_MATCH_NOSMART plus smartmatch
+
 =head2 XPK_LITERAL
 
 I<atomic, can probe, emits nothing.>
